.. Copyright (C) 2016 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2016 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

``debops.debops_api`` can be used to setup the `DebOps API`__.

.. __: https://github.com/debops/debops-api
